# Testing WebSockets

You can use the same `TestClient` to test WebSockets.

For this, you use the `TestClient` in a `with` statement, connecting to the WebSocket:

```Python hl_lines="27 28 29 30 31"
{!../../../docs_src/app_testing/tutorial002.py!}
```
